﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Web;
using System.Web.Mvc;

namespace Telerik.Web.Mvc.UI
{
    using Fluent;

    public static class TelerikBuilderExtensions
    {
        public static void Render(this DropDownListBuilder dropDownListBuilder, bool editable)
        {
            if (editable)
            {
                dropDownListBuilder.Render();
            }
            else
            {
                TagBuilder tagBuilder = new TagBuilder("input");
                tagBuilder.MergeAttribute("type", "text");
                tagBuilder.MergeAttribute("id", dropDownListBuilder.ToComponent().Name);
                tagBuilder.MergeAttribute("value", dropDownListBuilder.ToComponent().Value);
                tagBuilder.MergeAttribute("class", "readOnly");
                tagBuilder.MergeAttribute("readonly", "read-only");

                dropDownListBuilder.ToComponent().ViewContext.Writer.Write(tagBuilder.ToString());
            }
        }

        public static void Render(this DatePickerBuilder datePickerBuilder, bool editable)
        {
            if (editable)
            {
                datePickerBuilder.Render();
            }
            else
            {
                TagBuilder tagBuilder = new TagBuilder("input");
                tagBuilder.MergeAttribute("type", "text");
                tagBuilder.MergeAttribute("id", datePickerBuilder.ToComponent().Name);
                tagBuilder.MergeAttribute("value", datePickerBuilder.ToComponent().Value != null
                    ? datePickerBuilder.ToComponent().Value.Value.ToShortDateString()
                    : string.Empty);
                tagBuilder.MergeAttribute("class", "readOnly");
                tagBuilder.MergeAttribute("readonly", "read-only");

                datePickerBuilder.ToComponent().ViewContext.Writer.Write(tagBuilder.ToString());
            }
        }

        public static void RenderAjax<T>(this GridBuilder<T> grid) where T : class
        {
            grid.Render();
            StringWriter sw = new StringWriter();
            grid.ToComponent().WriteInitializationScript(sw);

            TagBuilder tagBuilder = new TagBuilder("input");
            tagBuilder.MergeAttribute("type", "hidden");
            tagBuilder.MergeAttribute("id", string.Format("{0}_Create_tGrid", grid.ToComponent().Name));
            tagBuilder.MergeAttribute("value", sw.GetStringBuilder().ToString());

            grid.ToComponent().ViewContext.Writer.Write(tagBuilder.ToString());
        }

        public static void RenderAjax(this ComboBoxBuilder comboBoxBuilder)
        {
            comboBoxBuilder.Render();
            StringWriter sw = new StringWriter();
            comboBoxBuilder.ToComponent().WriteInitializationScript(sw);

            TagBuilder tagBuilder = new TagBuilder("input");
            tagBuilder.MergeAttribute("type", "hidden");
            tagBuilder.MergeAttribute("id", string.Format("{0}_Create_tComboBox", comboBoxBuilder.ToComponent().Name));
            tagBuilder.MergeAttribute("value", sw.GetStringBuilder().ToString());

            comboBoxBuilder.ToComponent().ViewContext.Writer.Write(tagBuilder.ToString());
        }

        public static void RenderAjax(this DatePickerBuilder datePickerBuilder)
        {
            datePickerBuilder.Render();
            StringWriter sw = new StringWriter();
            datePickerBuilder.ToComponent().WriteInitializationScript(sw);

            TagBuilder tagBuilder = new TagBuilder("input");
            tagBuilder.MergeAttribute("type", "hidden");
            tagBuilder.MergeAttribute("id", string.Format("{0}_Create_tDatePicker", datePickerBuilder.ToComponent().Name));
            tagBuilder.MergeAttribute("value", sw.GetStringBuilder().ToString());

            datePickerBuilder.ToComponent().ViewContext.Writer.Write(tagBuilder.ToString());
        }
    }
}
